<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="119"/>
        <source>Sndfile Plugin</source>
        <translation>Sndfile Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="122"/>
        <source>PCM Files</source>
        <translation>PCM Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="225"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>Sndfile Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="226"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Qmmp Sndfile Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="227"/>
        <source>Compiled against</source>
        <translation>Dayanarak derlendi</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="228"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
